Eflags

Enum Eflags 

pub enum Eflags {
    None,
    R,
    W,
    RW,
}
Describes if an instruction uses EFLAGS, and whether it reads, writes, or reads/writes the EFLAGS register. In the future, we might want to model specific EFLAGS bits instead of the entire EFLAGS register. Some related discussion in this GitHub issue https://github.com/bytecodealliance/wasmtime/issues/10298

Variants



None



R



W



RW

Implementations

Source

impl Eflags

pub fn is_read(&self) -> bool

Returns whether this represents a read of any bit in the EFLAGS register.

pub fn is_write(&self) -> bool

Returns whether this represents a writes to any bit in the EFLAGS register.